'use strict';

const assign = require('object-assign');
const stylelint = require('stylelint');
const ruleName = 'at-rule-import-no-underscore';
const messages = stylelint.utils.ruleMessages(ruleName, {
  rejected: 'Avoid leading underscores in import statements',
});

const arrayContains = (searchItem, array) =>
  array.indexOf(searchItem) > -1;

module.exports = stylelint.createPlugin(ruleName, (enabled) =>
  (root, result) => {
    const validOptions = stylelint.utils.validateOptions(result, ruleName, {
      actual: enabled,
      possible: [true, false]
    });

    const checkForElseStatement = (atRule) => {
      if (atRule.name !== 'import') { return; }

      const params = atRule.params.replace(/'|"/g, '');
      let fileName = '';
      let importPathParts = [];

      if (params.indexOf('/') > -1) {
        importPathParts = params.split('/');
        fileName = importPathParts[importPathParts.length - 1];
      } else {
        fileName = params;
      }

      if (enabled && fileName.substring(0, 1) === '_') {
        stylelint.utils.report({
          ruleName: ruleName,
          result: result,
          node: atRule,
          message: messages.rejected
        });
      }
    };

    if (!validOptions) {
      return;
    }

    root.walkAtRules(checkForElseStatement);
  }
);

module.exports.ruleName = ruleName;
module.exports.messages = messages;
